--[[----------------------------------------------------------------------------
Copyright (c) 2011, Danny Fritz <dannyfritz@gmail.com>
http://creativecommons.org/licenses/by/3.0/
Licensed under the Creative Commons Attribution 3.0 Unported License.
--]]----------------------------------------------------------------------------

local Splash = Gamestate:addState('Splash')

local Tween = require 'lib.tween.tween'
local Object = require 'splash.Object'

local NEXTSTATE = 'Menu'
local WIDTH = 800
local HEIGHT = 600

local leaf
local face
local text
local pixel_effect
local old_background_color
local music

--------------------------------------------------------------------------------
function Splash:enteredState()
	old_background_color = {love.graphics.getBackgroundColor()}
	love.graphics.setBackgroundColor(254, 153, 0)

	music = love.audio.newSource('splash/music.ogg')
	music:play()

	local leaf_image = love.graphics.newImage('splash/leaf.png')
	leaf = Object:new(leaf_image, {x=800, y=-120})
	Tween(5, leaf, {x=100}, 'inOutSine',
			Tween, 4, leaf, {x=520}, 'inOutSine')
	Tween(5, leaf, {y=-40}, 'outInSine',
			Tween, 4, leaf, {y=10}, 'outInSine')
	Tween(5, leaf, {angle=-0.5}, 'inOutSine',
			Tween, 4, leaf, {angle=0}, 'inOutSine')

	local face_image = love.graphics.newImage('splash/face.png')
	face = Object:new(face_image,
			{x=390, y=300, scale_x=0.75, scale_y=0.75, alpha=0, offset_x=159, offset_y=175})
	Tween(7.5, face, {}, 'linear',
			Tween, 1.5, face, {scale_x=1, scale_y=1}, 'linear')
	Tween(8, face, {}, 'linear',
			Tween, 1.5, face, {alpha=255}, 'linear')

	local text_image = love.graphics.newImage('splash/TechnoCat.png')
	text = Object:new(text_image, {x=90, y=490, alpha=0})
	Tween(8, text, {}, 'linear',
			Tween, 1, text, {alpha=255}, 'linear')
	
	Tween(12, leaf, {}, 'linear',
			Tween, 2, leaf, {alpha=0}, 'linear',
			gamestate.gotoState, gamestate, NEXTSTATE)
	
	Tween(12, face, {}, 'linear',
			Tween, 2, face, {alpha=0}, 'linear')
	
	Tween(12, text, {}, 'linear',
			Tween, 2, text, {alpha=0}, 'linear')
	
end

--------------------------------------------------------------------------------
function Splash:exitedState()
	love.graphics.setBackgroundColor(unpack(old_background_color))
end

--------------------------------------------------------------------------------
function Splash:update(dt)
	Tween.update(dt)
end

--------------------------------------------------------------------------------
function Splash:draw()
	leaf:draw()
	face:draw()
	text:draw()
end

--------------------------------------------------------------------------------
function Splash:keypressed(key, unicode)
	if key == ' ' or key == 'return' or key == 'kpenter' or key == 'escape' then
		gamestate:gotoState(NEXTSTATE)
	end
end

--------------------------------------------------------------------------------
function Splash:mousepressed(x, y, button)
	gamestate:gotoState(NEXTSTATE)
	--Let the player press things for animations!
end

--------------------------------------------------------------------------------
function Splash:joystickpressed(joystick, button)
	gamestate:gotoState(NEXTSTATE)
end
